/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
export declare type AuctionHouseArgs = {
    auctionHouseFeeAccount: web3.PublicKey;
    auctionHouseTreasury: web3.PublicKey;
    treasuryWithdrawalDestination: web3.PublicKey;
    feeWithdrawalDestination: web3.PublicKey;
    treasuryMint: web3.PublicKey;
    authority: web3.PublicKey;
    creator: web3.PublicKey;
    bump: number;
    treasuryBump: number;
    feePayerBump: number;
    sellerFeeBasisPoints: number;
    requiresSignOff: boolean;
    canChangeSalePrice: boolean;
    escrowPaymentBump: number;
    hasAuctioneer: boolean;
    auctioneerPdaBump: number;
};
export declare class AuctionHouse implements AuctionHouseArgs {
    readonly auctionHouseFeeAccount: web3.PublicKey;
    readonly auctionHouseTreasury: web3.PublicKey;
    readonly treasuryWithdrawalDestination: web3.PublicKey;
    readonly feeWithdrawalDestination: web3.PublicKey;
    readonly treasuryMint: web3.PublicKey;
    readonly authority: web3.PublicKey;
    readonly creator: web3.PublicKey;
    readonly bump: number;
    readonly treasuryBump: number;
    readonly feePayerBump: number;
    readonly sellerFeeBasisPoints: number;
    readonly requiresSignOff: boolean;
    readonly canChangeSalePrice: boolean;
    readonly escrowPaymentBump: number;
    readonly hasAuctioneer: boolean;
    readonly auctioneerPdaBump: number;
    private constructor();
    static fromArgs(args: AuctionHouseArgs): AuctionHouse;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [AuctionHouse, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<AuctionHouse>;
    static deserialize(buf: Buffer, offset?: number): [AuctionHouse, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        auctionHouseFeeAccount: string;
        auctionHouseTreasury: string;
        treasuryWithdrawalDestination: string;
        feeWithdrawalDestination: string;
        treasuryMint: string;
        authority: string;
        creator: string;
        bump: number;
        treasuryBump: number;
        feePayerBump: number;
        sellerFeeBasisPoints: number;
        requiresSignOff: boolean;
        canChangeSalePrice: boolean;
        escrowPaymentBump: number;
        hasAuctioneer: boolean;
        auctioneerPdaBump: number;
    };
}
export declare const auctionHouseBeet: beet.BeetStruct<AuctionHouse, AuctionHouseArgs & {
    accountDiscriminator: number[];
}>;
